:: *****************************************************************************
:: *
:: * E M B E D D E D   W I Z A R D   P R O J E C T
:: *
:: *****************************************************************************
:: * FlashDownload.cmd
:: *
:: * This script uses the Renesas Flash Programmer to program the internal and
:: * optionally also the external flash memory of a Renesas device.
:: *
:: * Usage:    FlashDownload.cmd <mot-file> [options]
:: *
:: * Options:
:: *   separateConsole          -  open a separate console window
:: *   reset                    -  reset target after flashing
:: *
:: *****************************************************************************


@ECHO OFF
setlocal ENABLEDELAYEDEXPANSION

:: initialize variables
set externalLoaderExtension=
set imageStartAddress=

echo.

:: Load commandline options
call :getCommadlineOptions "%*"


:: display usage, if there is no parameter
if [%1] == [] (
  echo FlashDownload.cmd
  echo.
  echo This script uses the Renesas Flash Programmer to program the internal and
  echo optionally also the external flash memory of a Renesas device.
  echo.
  echo Usage:    FlashDownload.cmd [mot-file] [options]
  echo.
  echo Options:
  echo   separateConsole          -  open a separate console window
  echo   reset                    -  reset target after flashing
  echo.
  call pause
  exit
)

:: change size of console
if [%separateConsole%] == [set] (
  title Programming taget using Renesas Flash Programmer ...
  mode con:cols=140 lines=50
)

:: load configuration
for /F "delims= eol=:" %%A in (%~dps0FlashDownload.cfg) do set "%%A"


:: do some checks

if not exist "%RenesasFlashProgrammerPath%" (
  echo.
  echo Renesas Flash Programmer check failed:
  echo Renesas Flash Programmer not found on path:
  echo "%RenesasFlashProgrammerPath%".
  echo Please install the Renesas Flash Programmer or adapt the setting for
  echo 'RenesasFlashProgrammerPath' in file '\Application\FlashDownload\FlashDownload.cfg'.
  echo.
  echo Renesas Flash Programmer can be downloaded at:
  echo https://www.renesas.com/us/en/software-tool/renesas-flash-programmer-programming-gui
  echo.
  call :doPause
  exit
)


:startFlashing
set RenesasFlashProgrammer="%RenesasFlashProgrammerPath%\rfp-cli.exe" %RenesasFlashProgrammerParams%


echo Programming file '%~nx1' to target using Renesas Flash Programmer ...
%RenesasFlashProgrammer% %1
echo.

if %ERRORLEVEL% == 0 (
  echo '%~nx1' successfully flashed !!
  if [%separateConsole%] == [set] (
    timeout /t 3 > NUL
  )
) ELSE (
  echo ERROR - flashing failed!
  echo.
  call :doPause
)
exit /B 0



:getCommadlineOptions
  :: replace equal signs by ':'
  for /f "tokens=1-10 delims==" %%a in (%1) do set list3=%%a:%%b:%%c:%%d:%%e:%%f:%%g:%%h:%%i:%%j

  for %%i in (%list3%) do (
    set var=%%i
    call :setvar !var::= !
  )
  exit /B 0

:setvar
  if x%2==x (
    set %1=set
  ) else (
    set %1=%2
  )
  exit /B 0

:doPause
  if [%separateConsole%] == [set] (
    pause
  )
  exit /B 0