/***********************************************************************************************************************
* DISCLAIMER
* This software is supplied by Renesas Electronics Corporation and is only intended for use with Renesas products.
* No other uses are authorized. This software is owned by Renesas Electronics Corporation and is protected under all
* applicable laws, including copyright laws. 
* THIS SOFTWARE IS PROVIDED "AS IS" AND RENESAS MAKES NO WARRANTIES REGARDING THIS SOFTWARE, WHETHER EXPRESS, IMPLIED
* OR STATUTORY, INCLUDING BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
* NON-INFRINGEMENT.  ALL SUCH WARRANTIES ARE EXPRESSLY DISCLAIMED.TO THE MAXIMUM EXTENT PERMITTED NOT PROHIBITED BY
* LAW, NEITHER RENESAS ELECTRONICS CORPORATION NOR ANY OF ITS AFFILIATED COMPANIES SHALL BE LIABLE FOR ANY DIRECT,
* INDIRECT, SPECIAL, INCIDENTAL OR CONSEQUENTIAL DAMAGES FOR ANY REASON RELATED TO THIS SOFTWARE, EVEN IF RENESAS OR
* ITS AFFILIATES HAVE BEEN ADVISED OF THE POSSIBILITY OF SUCH DAMAGES.
* Renesas reserves the right, without notice, to make changes to this software and to discontinue the availability 
* of this software. By using this software, you agree to the additional terms and conditions found by accessing the 
* following link:
* http://www.renesas.com/disclaimer
*
* Copyright (C) 2022 Renesas Electronics Corporation. All rights reserved.
***********************************************************************************************************************/

/***********************************************************************************************************************
* File Name        : Config_RTC.c
* Component Version: 1.8.0
* Device(s)        : R5F572NNHxFB
* Description      : This file implements device driver for Config_RTC.
***********************************************************************************************************************/

/***********************************************************************************************************************
Pragma directive
***********************************************************************************************************************/
/* Start user code for pragma. Do not edit comment generated here */
/* End user code. Do not edit comment generated here */

/***********************************************************************************************************************
Includes
***********************************************************************************************************************/
#include "r_cg_macrodriver.h"
#include "Config_RTC.h"
/* Start user code for include. Do not edit comment generated here */
/* End user code. Do not edit comment generated here */
#include "r_cg_userdefine.h"

/***********************************************************************************************************************
Global variables and functions
***********************************************************************************************************************/
/* Start user code for global. Do not edit comment generated here */
/* End user code. Do not edit comment generated here */

/***********************************************************************************************************************
* Function Name: R_Config_RTC_Create
* Description  : This function initializes the RTC module
* Arguments    : None
* Return Value : None
***********************************************************************************************************************/

void R_Config_RTC_Create(void)
{
    uint16_t w_count;
    uint32_t rw_count;
    volatile uint32_t dummy;

    /* Disable ALM, PRD and CUP interrupts */
    IEN(RTC, ALM) = 0U;
    IEN(RTC, PRD) = 0U;

    /* Main Clock Oscillator Forced Oscillation */
    SYSTEM.MOFCR.BIT.MOFXIN = 1U;

    /* Set RTC clock source */
    RTC.RCR4.BYTE = _01_RTC_SOURCE_SELECT_MAIN_FORCED;

    /* Wait for 6 main-clock cycles */
    for (w_count = 0U; w_count < _0013_RTC_MAIN_6_CYCLE_WAIT; w_count++)
    {
        nop();
    }

    /* Disable sub-clock oscillator */
    while (0U != RTC.RCR3.BIT.RTCEN)
    {
        RTC.RCR3.BIT.RTCEN = 0U;
    }

    /* RTC cold start with sub-clock source or RTC start with main clock source */
    if((0 == SYSTEM.RSTSR1.BIT.CWSF) || (_01_RTC_SOURCE_SELECT_MAIN_FORCED == RTC.RCR4.BYTE))
    {

        /* Stop all counters */
        RTC.RCR2.BYTE = 0x00U;
        while (RTC.RCR2.BIT.START != 0U)
        {
            /* Wait for the register modification to complete */
        }

        /* Set frequency register H/L */
        RTC.RFRH.WORD = 0x0001U;
        RTC.RFRL.WORD = 0xE847U;

        /* Select count mode */
        RTC.RCR2.BIT.CNTMD = 1U;
        while (RTC.RCR2.BIT.CNTMD != 1U)
        {
            /* Wait for the register modification to complete */
        }

        /* Execute RTC software reset */
        RTC.RCR2.BIT.RESET = 1U;
        while (RTC.RCR2.BIT.RESET != 0U)
        {
            /* Wait for the register modification to complete */
        }

         /* Stop RTC counter */
        RTC.RCR2.BIT.START = 0U;
        while (RTC.RCR2.BIT.START != 0U)
        {
            /* Wait for the register modification to complete */
        }

        /* Clear ALM,PRD,CUP IR */
        IR(RTC, ALM) = 0U;
        IR(RTC, PRD) = 0U;

        /* Clear the counters */
        RTC.BCNT0.BYTE = 0U;
        RTC.BCNT1.BYTE = 0U;
        RTC.BCNT2.BYTE = 0U;
        RTC.BCNT3.BYTE = 0U;
        RTC.RCR2.BYTE |= (_00_RTC_AUTO_ADJUSTMENT_DISABLE);

        /* Perform 4 read operations after writing */
        for (rw_count = 0U; rw_count < _04_FOUR_READ_COUNT; rw_count++)
        {
            dummy = RTC.RCR2.BYTE;
        }

        /* Set control registers */
        dummy = _00_RTC_ALARM_INT_DISABLE | _00_RTC_PERIOD_INT_DISABLE | _00_RTC_PERIODIC_INT_PERIOD_DISABLE;
        RTC.RCR1.BYTE = dummy;
        while (dummy != RTC.RCR1.BYTE)
        {
            /* Wait for this write to complete. */
        }

    }

    /* Set control registers */
    dummy = RTC.RCR1.BYTE | _00_RTC_CARRY_INT_DISABLE;
    RTC.RCR1.BYTE = dummy;
    while (dummy != RTC.RCR1.BYTE)
    {
        /* Wait for this write to complete. */
    }
    dummy = RTC.RCR2.BYTE | _00_RTC_RTCOUT_OUTPUT_DISABLE;
    RTC.RCR2.BYTE = dummy;
    while (dummy != RTC.RCR2.BYTE)
    {
        /* Wait for this write to complete. */
    }

    /* Set time capture */
    RTC.RTCCR0.BYTE = _00_RTC_TIME_CAPTURE_NO_EVENT | _00_RTC_TIME_CAPTURE_NOISE_FILTER_OFF | 
                      _00_RTC_TIME_CAPTURE_EVENT_DISABLE;
    RTC.RTCCR1.BYTE = _00_RTC_TIME_CAPTURE_NO_EVENT | _00_RTC_TIME_CAPTURE_NOISE_FILTER_OFF | 
                      _00_RTC_TIME_CAPTURE_EVENT_DISABLE;
    RTC.RTCCR2.BYTE = _00_RTC_TIME_CAPTURE_NO_EVENT | _00_RTC_TIME_CAPTURE_NOISE_FILTER_OFF | 
                      _00_RTC_TIME_CAPTURE_EVENT_DISABLE;

    R_Config_RTC_Create_UserInit();
}

/***********************************************************************************************************************
* Function Name: R_Config_RTC_Start
* Description  : This function starts RTC counter
* Arguments    : None
* Return Value : None
***********************************************************************************************************************/

void R_Config_RTC_Start(void)
{

    /* Set the START bit to 1 */
    RTC.RCR2.BIT.START = 1U;
    while (RTC.RCR2.BIT.START != 1U)
    {
        /* Wait for the register modification to complete */
    }

}

/***********************************************************************************************************************
* Function Name: R_Config_RTC_Stop
* Description  : This function stops RTC counter
* Arguments    : None
* Return Value : None
***********************************************************************************************************************/

void R_Config_RTC_Stop(void)
{

    /* Stop all counters */
    RTC.RCR2.BIT.START = 0U;
    while (RTC.RCR2.BIT.START != 0U)
    {
        /* Wait for the register modification to complete */
    }

}

/***********************************************************************************************************************
* Function Name: R_Config_RTC_Restart_BinaryCounter
* Description  : This function restarts RTC counter in binary mode
* Arguments    : None
* Return Value : None
***********************************************************************************************************************/

void R_Config_RTC_Restart_BinaryCounter(void)
{
    uint32_t rw_count;
    volatile uint32_t dummy;

    /* Disable ALM, PRD and CUP interrupts */
    IEN(RTC, ALM) = 0U;
    IEN(RTC, PRD) = 0U;

    /* Stop all counters */
    RTC.RCR2.BIT.START = 0U;
    while (RTC.RCR2.BIT.START != 0U)
    {
        /* Wait for the register modification to complete */
    }

    /* Execute RTC software reset */
    RTC.RCR2.BIT.RESET = 1U;
    while (RTC.RCR2.BIT.RESET != 0U)
    {
        /* Execute RTC software reset */
    }

    /* Set control registers */
    RTC.RCR2.BYTE |= (_00_RTC_RTCOUT_OUTPUT_DISABLE | _00_RTC_AUTO_ADJUSTMENT_DISABLE);

    /* Perform 4 read operations after writing */
    for (rw_count = 0U; rw_count < _04_FOUR_READ_COUNT; rw_count++)
    {
        dummy = RTC.RCR2.BYTE;
    }
    /* Clear counters */
    RTC.BCNT0.BYTE = 0U;
    RTC.BCNT1.BYTE = 0U;
    RTC.BCNT2.BYTE = 0U;
    RTC.BCNT3.BYTE = 0U;

    /* Set the START bit to 1 */
    RTC.RCR2.BIT.START = 1U;
    while (RTC.RCR2.BIT.START != 1U)
    {
        /* Wait for the register modification to complete */
    }
}

/***********************************************************************************************************************
* Function Name: R_Config_RTC_Get_BinaryCounterValue
* Description  : This function get RTC binary counter value
* Arguments    : counter_read_val -
*                    counter read pointer
* Return Value : None
***********************************************************************************************************************/

void R_Config_RTC_Get_BinaryCounterValue(uint32_t * const counter_read_val)
{
    /* Store RCR1 status */
    uint32_t dummy = RTC.RCR1.BYTE;

    /* Enable RTC CUP interrupt */
    RTC.RCR1.BYTE |= _02_RTC_CARRY_INT_ENABLE;
    do
    {
        ICU.PIBR6.BYTE = 0x02U;

        /* Read counter registers */
        *counter_read_val = (uint32_t)RTC.BCNT0.BYTE;
        (*counter_read_val) |= ((uint32_t)RTC.BCNT1.BYTE << 8U);
        (*counter_read_val) |= ((uint32_t)RTC.BCNT2.BYTE << 16U);
        (*counter_read_val) |= ((uint32_t)RTC.BCNT3.BYTE << 24U);

    } while ((ICU.PIBR6.BYTE & 0x02U) != 0U);

    /* Restore back RCR1 status */
    RTC.RCR1.BYTE = dummy;

}

/***********************************************************************************************************************
* Function Name: R_Config_RTC_Set_BinaryCounterValue
* Description  : This function set RTC binary counter value
* Arguments    : counter_write_val -
*                    counter write pointer
* Return Value : None
***********************************************************************************************************************/

void R_Config_RTC_Set_BinaryCounterValue(uint32_t counter_write_val)
{
    uint32_t rw_count;
    volatile uint32_t dummy;

    /* Stop all counters */
    RTC.RCR2.BIT.START = 0U;
    while (RTC.RCR2.BIT.START != 0U)
    {
        /* Ensure the clock is stopped while configuring it. */
    }

    /* Execute RTC software reset */
    RTC.RCR2.BIT.RESET = 1U;
    while (RTC.RCR2.BIT.RESET != 0U)
    {
        /* Wait for the reset to complete */
    }

    /* Set control registers */
    RTC.RCR2.BYTE |= (_00_RTC_RTCOUT_OUTPUT_DISABLE | _00_RTC_AUTO_ADJUSTMENT_DISABLE);

    /* Perform 4 read operations after writing */
    for (rw_count = 0U; rw_count < _04_FOUR_READ_COUNT; rw_count++)
    {
        dummy = RTC.RCR2.BYTE;
    }

    /* Set the counters */
    RTC.BCNT0.BYTE = (uint8_t)(counter_write_val & 0x000000FFUL);
    RTC.BCNT1.BYTE = (uint8_t)((counter_write_val & 0x0000FF00UL) >> 8U);
    RTC.BCNT2.BYTE = (uint8_t)((counter_write_val & 0x00FF0000UL) >> 16U);
    RTC.BCNT3.BYTE = (uint8_t)((counter_write_val & 0xFF000000UL) >> 24U);

}

/* Start user code for adding. Do not edit comment generated here */
/* End user code. Do not edit comment generated here */
