/*******************************************************************************
*
* E M B E D D E D   W I Z A R D   P R O J E C T
*
*                                                Copyright (c) TARA Systems GmbH
*                                    written by Paul Banach and Manfred Schweyer
*
********************************************************************************
*
* This software is delivered "as is" and shows the usage of other software
* components. It is provided as an example software which is intended to be
* modified and extended according to particular requirements.
*
* TARA Systems hereby disclaims all warranties and conditions with regard to the
* software, including all implied warranties and conditions of merchantability
* and non-infringement of any third party IPR or other rights which may result
* from the use or the inability to use the software.
*
********************************************************************************
*
* DESCRIPTION:
*   This file is part of the interface (glue layer) between an Embedded Wizard
*   generated UI application and the board support package (BSP) of a dedicated
*   target.
*   This template is responsible to initialize the display hardware of the board
*   and to provide the necessary access to update the display content.
*   The color format of the framebuffer has to correspond to the color format
*   of the Graphics Engine.
*
*   Important: This file is intended to be used as a template. Please adapt the
*   implementation according your particular hardware.
*
*******************************************************************************/

#include "r_smc_entry.h"
#include "r_glcdc_rx_if.h"
#include "r_glcdc_rx_pinset.h"

/* Header files for RPBRX72N Envision board output by QE for Display [RX] */
#include "..\..\..\r_image_config_RX72N_Envision.h"
#include "..\..\..\r_lcd_timing_RX72N_Envision.h"

#include <stdlib.h>
#include <stdint.h>
#include <stdbool.h>
#include <string.h>

#include "ewconfig.h"
#include "ewrte.h"
#include "ewgfx.h"
#include "ewextgfx.h"
#include "ewgfxdefs.h"

#include "ew_bsp_display.h"
#include "ew_bsp_clock.h"


/* Using GLCDC fit module */
static glcdc_cfg_t gs_glcdc_init_cfg;                   /* Argument of R_GLCDC_Open function. */
static volatile bool gs_first_interrupt_flag;           /* It is used for interrupt control of GLCDC module */
static glcdc_runtime_cfg_t s_runtime_cfg;

#if EW_USE_DOUBLE_BUFFER == 1

  static volatile uint32_t      PendingFramebuffer = 0;

#else

  static volatile unsigned long VSyncTime          = 0;
  static volatile unsigned long VSyncDuration      = 0;

#endif

volatile unsigned long        CycleCounter       = 0;

/* ---- Setting gamma parameters to be adjusted with QE for Display [RX] ---- */
/* Gamma Red data table */
static const gamma_correction_t gs_gamma_table_r =
{
    /* Gain (Adjusted value by QE) */
    { IMGC_GAMMA_R_GAIN_00, IMGC_GAMMA_R_GAIN_01, IMGC_GAMMA_R_GAIN_02, IMGC_GAMMA_R_GAIN_03,
      IMGC_GAMMA_R_GAIN_04, IMGC_GAMMA_R_GAIN_05, IMGC_GAMMA_R_GAIN_06, IMGC_GAMMA_R_GAIN_07,
      IMGC_GAMMA_R_GAIN_08, IMGC_GAMMA_R_GAIN_09, IMGC_GAMMA_R_GAIN_10, IMGC_GAMMA_R_GAIN_11,
      IMGC_GAMMA_R_GAIN_12, IMGC_GAMMA_R_GAIN_13, IMGC_GAMMA_R_GAIN_14, IMGC_GAMMA_R_GAIN_15 },

    /* Threshold (Adjusted value by QE) */
    { IMGC_GAMMA_R_TH_01, IMGC_GAMMA_R_TH_02, IMGC_GAMMA_R_TH_03, IMGC_GAMMA_R_TH_04,
      IMGC_GAMMA_R_TH_05, IMGC_GAMMA_R_TH_06, IMGC_GAMMA_R_TH_07, IMGC_GAMMA_R_TH_08,
      IMGC_GAMMA_R_TH_09, IMGC_GAMMA_R_TH_10, IMGC_GAMMA_R_TH_11, IMGC_GAMMA_R_TH_12,
      IMGC_GAMMA_R_TH_13, IMGC_GAMMA_R_TH_14, IMGC_GAMMA_R_TH_15 }
};

/* Gamma Green data table */
static const gamma_correction_t gs_gamma_table_g =
{
    /* Gain (Adjusted value by QE) */
    { IMGC_GAMMA_G_GAIN_00, IMGC_GAMMA_G_GAIN_01, IMGC_GAMMA_G_GAIN_02, IMGC_GAMMA_G_GAIN_03,
      IMGC_GAMMA_G_GAIN_04, IMGC_GAMMA_G_GAIN_05, IMGC_GAMMA_G_GAIN_06, IMGC_GAMMA_G_GAIN_07,
      IMGC_GAMMA_G_GAIN_08, IMGC_GAMMA_G_GAIN_09, IMGC_GAMMA_G_GAIN_10, IMGC_GAMMA_G_GAIN_11,
      IMGC_GAMMA_G_GAIN_12, IMGC_GAMMA_G_GAIN_13, IMGC_GAMMA_G_GAIN_14, IMGC_GAMMA_G_GAIN_15 },

    /* Threshold (Adjusted value by QE) */
    { IMGC_GAMMA_G_TH_01, IMGC_GAMMA_G_TH_02, IMGC_GAMMA_G_TH_03, IMGC_GAMMA_G_TH_04,
      IMGC_GAMMA_G_TH_05, IMGC_GAMMA_G_TH_06, IMGC_GAMMA_G_TH_07, IMGC_GAMMA_G_TH_08,
      IMGC_GAMMA_G_TH_09, IMGC_GAMMA_G_TH_10, IMGC_GAMMA_G_TH_11, IMGC_GAMMA_G_TH_12,
      IMGC_GAMMA_G_TH_13, IMGC_GAMMA_G_TH_14, IMGC_GAMMA_G_TH_15 }
};

/* Gamma Blue data table */
static const gamma_correction_t gs_gamma_table_b =
{
    /* Gain (Adjusted value by QE) */
    { IMGC_GAMMA_B_GAIN_00, IMGC_GAMMA_B_GAIN_01, IMGC_GAMMA_B_GAIN_02, IMGC_GAMMA_B_GAIN_03,
      IMGC_GAMMA_B_GAIN_04, IMGC_GAMMA_B_GAIN_05, IMGC_GAMMA_B_GAIN_06, IMGC_GAMMA_B_GAIN_07,
      IMGC_GAMMA_B_GAIN_08, IMGC_GAMMA_B_GAIN_09, IMGC_GAMMA_B_GAIN_10, IMGC_GAMMA_B_GAIN_11,
      IMGC_GAMMA_B_GAIN_12, IMGC_GAMMA_B_GAIN_13, IMGC_GAMMA_B_GAIN_14, IMGC_GAMMA_B_GAIN_15 },

    /* Threshold (Adjusted value by QE) */
    { IMGC_GAMMA_B_TH_01, IMGC_GAMMA_B_TH_02, IMGC_GAMMA_B_TH_03, IMGC_GAMMA_B_TH_04,
      IMGC_GAMMA_B_TH_05, IMGC_GAMMA_B_TH_06, IMGC_GAMMA_B_TH_07, IMGC_GAMMA_B_TH_08,
      IMGC_GAMMA_B_TH_09, IMGC_GAMMA_B_TH_10, IMGC_GAMMA_B_TH_11, IMGC_GAMMA_B_TH_12,
      IMGC_GAMMA_B_TH_13, IMGC_GAMMA_B_TH_14, IMGC_GAMMA_B_TH_15 }
};

static void board_port_setting (void)
{
    /* ---- Port setting ---- */
    /* LCD back light and display-on */
	PORT6.PODR.BIT.B7 = 1;  /* Back light */
	PORTB.PODR.BIT.B3 = 1;  /* Display */
	PORT6.PDR.BIT.B7 = 1;
	PORTB.PDR.BIT.B3 = 1;

} /* End of function board_port_setting() */

/*******************************************************************************
 * Outline      : GLCDC QE output parameter setting
 * Header       : none
 * Function Name: qe_for_display_parameter_set
 * Description  : Setting parameters to be adjusted with QE for Display [RX].
 *              : The definition written in the header file output by QE for Display [RX]
 *              : is set as the parameter of the GLCDC FIT module.
 * Arguments    : glcdc_cfg_t -
 *                  initial configuration parameter
 * Return Value : none
 *******************************************************************************/
static void qe_for_display_parameter_set (glcdc_cfg_t *glcdc_qe_cfg)
{
    /* Output timing */
    glcdc_qe_cfg->output.htiming.front_porch = LCD_CH0_W_HFP;
    glcdc_qe_cfg->output.htiming.back_porch  = LCD_CH0_W_HBP;
    glcdc_qe_cfg->output.htiming.display_cyc = EW_FRAME_BUFFER_WIDTH;
    glcdc_qe_cfg->output.htiming.sync_width  = LCD_CH0_W_HSYNC;

    glcdc_qe_cfg->output.vtiming.front_porch = LCD_CH0_W_VFP;
    glcdc_qe_cfg->output.vtiming.back_porch  = LCD_CH0_W_VBP;
    glcdc_qe_cfg->output.vtiming.display_cyc = LCD_CH0_DISP_VW;
    glcdc_qe_cfg->output.vtiming.sync_width  = LCD_CH0_W_VSYNC;

    /* Output format */
    glcdc_qe_cfg->output.format = LCD_CH0_OUT_FORMAT;

    /* Tcon polarity*/
    glcdc_qe_cfg->output.data_enable_polarity = LCD_CH0_TCON_POL_DE;
    glcdc_qe_cfg->output.hsync_polarity       = LCD_CH0_TCON_POL_HSYNC;
    glcdc_qe_cfg->output.vsync_polarity       = LCD_CH0_TCON_POL_VSYNC;

    /* Sync signal edge */
    glcdc_qe_cfg->output.sync_edge = LCD_CH0_OUT_EDGE;

    /* Output tcon pin */
    glcdc_qe_cfg->output.tcon_hsync = LCD_CH0_TCON_PIN_HSYNC;
    glcdc_qe_cfg->output.tcon_vsync = LCD_CH0_TCON_PIN_VSYNC;
    glcdc_qe_cfg->output.tcon_de    = LCD_CH0_TCON_PIN_DE;

    /* Correction circuit sequence */
    gs_glcdc_init_cfg.output.correction_proc_order = IMGC_OUTCTL_CALIB_ROUTE;

    /* Brightness */
    glcdc_qe_cfg->output.brightness.enable = IMGC_BRIGHT_OUTCTL_ACTIVE;
    glcdc_qe_cfg->output.brightness.r      = IMGC_BRIGHT_OUTCTL_OFFSET_R;
    glcdc_qe_cfg->output.brightness.g      = IMGC_BRIGHT_OUTCTL_OFFSET_G;
    glcdc_qe_cfg->output.brightness.b      = IMGC_BRIGHT_OUTCTL_OFFSET_B;

    /* Contrast */
    glcdc_qe_cfg->output.contrast.enable = IMGC_CONTRAST_OUTCTL_ACTIVE;
    glcdc_qe_cfg->output.contrast.r      = IMGC_CONTRAST_OUTCTL_GAIN_R;
    glcdc_qe_cfg->output.contrast.g      = IMGC_CONTRAST_OUTCTL_GAIN_G;
    glcdc_qe_cfg->output.contrast.b      = IMGC_CONTRAST_OUTCTL_GAIN_B;

    /* Gamma */
    glcdc_qe_cfg->output.gamma.enable = IMGC_GAMMA_ACTIVE;
    glcdc_qe_cfg->output.gamma.p_r    = (gamma_correction_t *) &gs_gamma_table_r;
    glcdc_qe_cfg->output.gamma.p_g    = (gamma_correction_t *) &gs_gamma_table_g;
    glcdc_qe_cfg->output.gamma.p_b    = (gamma_correction_t *) &gs_gamma_table_b;

    /* Dethering */
    glcdc_qe_cfg->output.dithering.dithering_on        = IMGC_DITHER_ACTIVE;
    glcdc_qe_cfg->output.dithering.dithering_mode      = IMGC_DITHER_MODE;
    glcdc_qe_cfg->output.dithering.dithering_pattern_a = IMGC_DITHER_2X2_PA;
    glcdc_qe_cfg->output.dithering.dithering_pattern_b = IMGC_DITHER_2X2_PB;
    glcdc_qe_cfg->output.dithering.dithering_pattern_c = IMGC_DITHER_2X2_PC;
    glcdc_qe_cfg->output.dithering.dithering_pattern_d = IMGC_DITHER_2X2_PD;

} /* End of function qe_for_display_parameter_set() */



static void glcdc_callback (void * pdata)
{
  if (false == gs_first_interrupt_flag)
  {
    gs_first_interrupt_flag = true;
    /* Do nothing */
  }
  else
  {
    glcdc_callback_args_t * p_decode;
    p_decode = (glcdc_callback_args_t *) pdata;

    if (GLCDC_EVENT_GR1_UNDERFLOW == p_decode->event)
    {
      nop(); /* GR1 underflow , if necessary */
    }
    else if (GLCDC_EVENT_GR2_UNDERFLOW == p_decode->event)
    {
      nop(); /* GR2 underflow , if necessary */
    }
    else /* GLCDC_EVENT_LINE_DETECTION */
    {
      #if EW_USE_DOUBLE_BUFFER == 1

        /* as soon as V-sync interrupt occurs, no buffer is pending */
        if ( PendingFramebuffer )
          PendingFramebuffer = 0;

      #else

        unsigned long curTicks = CycleCounter;
        VSyncDuration = curTicks - VSyncTime;
        VSyncTime = curTicks;

      #endif
    }
  }
}


/* Helper function to sync on a certain line number updated by the display.
   This function is necessary when the system is used in single framebuffer mode. */
#if EW_USE_DOUBLE_BUFFER == 0
static void SyncOnLine( int aLine )
{
  unsigned long ticksTillRequestedLine;
  unsigned long localVSyncTime;

  /* line interrupt is configured to begin of front porch area - we have to add vertical
     front porch and vertical back porch to start on the desired visible line */
  aLine += LCD_CH0_W_VFP + LCD_CH0_W_VSYNC + LCD_CH0_W_VBP;

  /* calculate time tick that corresponds to requested line */
  ticksTillRequestedLine = aLine * VSyncDuration / ( LCD_CH0_W_VSYNC + LCD_CH0_W_VBP + EW_FRAME_BUFFER_HEIGHT + LCD_CH0_W_VFP );

  CPU_LOAD_SET_IDLE();

  /* if requested line is missed, wait for next display frame (next V-sync) */
  while (( CycleCounter - VSyncTime ) > ticksTillRequestedLine )
    ;

  /* wait for requested line in current display frame */
  localVSyncTime = VSyncTime;
  while (( CycleCounter - localVSyncTime ) < ticksTillRequestedLine )
    ;

  CPU_LOAD_SET_ACTIVE();
}
#endif


/*******************************************************************************
* FUNCTION:
*   EwBspDisplayInit
*
* DESCRIPTION:
*   The function EwBspDisplayInit initializes the display hardware and returns
*   the display parameter.
*
* ARGUMENTS:
*   aGuiWidth,
*   aGuiHeight   - Size of the GUI in pixel.
*   aDisplayInfo - Display info data structure.
*
* RETURN VALUE:
*   Returns 1 if successful, 0 otherwise.
*
*******************************************************************************/
int EwBspDisplayInit( int aGuiWidth, int aGuiHeight, XDisplayInfo* aDisplayInfo )
{
  EW_UNUSED_ARG( aGuiWidth );
  EW_UNUSED_ARG( aGuiHeight );

  glcdc_in_format_t format;
  uint32_t          offset;
  uint32_t          clut;
  glcdc_err_t       ret;

#if ( EW_FRAME_BUFFER_COLOR_FORMAT == EW_FRAME_BUFFER_COLOR_FORMAT_RGB565 )
  format = GLCDC_IN_FORMAT_16BITS_RGB565;
  offset = EW_FRAME_BUFFER_WIDTH * 2;
  clut = 0;
#elif ( EW_FRAME_BUFFER_COLOR_FORMAT == EW_FRAME_BUFFER_COLOR_FORMAT_Index8 )
  format = GLCDC_IN_FORMAT_CLUT8;
  offset = EW_FRAME_BUFFER_WIDTH;
  clut = 1;
#elif ( EW_FRAME_BUFFER_COLOR_FORMAT == EW_FRAME_BUFFER_COLOR_FORMAT_LumA44 )
  format = GLCDC_IN_FORMAT_CLUT8;
  offset = EW_FRAME_BUFFER_WIDTH;
  clut = 1;
#endif

  /* ==== QE for Display [RX] setting parameter ==== */
  qe_for_display_parameter_set( &gs_glcdc_init_cfg );

  /* ==== User setting parameter ==== */
  /* ---- Graphic 2 setting ---- */
  /* Image format */
  gs_glcdc_init_cfg.input[GLCDC_FRAME_LAYER_2].p_base        = (uint32_t *) EW_FRAME_BUFFER_ADDR;
  gs_glcdc_init_cfg.input[GLCDC_FRAME_LAYER_2].hsize         = EW_FRAME_BUFFER_WIDTH;
  gs_glcdc_init_cfg.input[GLCDC_FRAME_LAYER_2].vsize         = EW_FRAME_BUFFER_HEIGHT;
  gs_glcdc_init_cfg.input[GLCDC_FRAME_LAYER_2].offset        = offset;
  gs_glcdc_init_cfg.input[GLCDC_FRAME_LAYER_2].format        = format;
  gs_glcdc_init_cfg.input[GLCDC_FRAME_LAYER_2].frame_edge    = false;
  gs_glcdc_init_cfg.input[GLCDC_FRAME_LAYER_2].coordinate.x  = 0;
  gs_glcdc_init_cfg.input[GLCDC_FRAME_LAYER_2].coordinate.y  = 0;
  gs_glcdc_init_cfg.input[GLCDC_FRAME_LAYER_2].bg_color.argb = 0x00CCCCCC;

  /* Alpha blend */
  gs_glcdc_init_cfg.blend[GLCDC_FRAME_LAYER_2].visible            = true;
  gs_glcdc_init_cfg.blend[GLCDC_FRAME_LAYER_2].blend_control      = GLCDC_BLEND_CONTROL_NONE;

  /* When blend_control is GLCDC_BLEND_CONTROL_NONE, setting values of following blend structure members are ignored. */
  gs_glcdc_init_cfg.blend[GLCDC_FRAME_LAYER_2].frame_edge         = false;
  gs_glcdc_init_cfg.blend[GLCDC_FRAME_LAYER_2].fixed_blend_value  = 0x00;
  gs_glcdc_init_cfg.blend[GLCDC_FRAME_LAYER_2].fade_speed         = 0x00;
  gs_glcdc_init_cfg.blend[GLCDC_FRAME_LAYER_2].start_coordinate.x = 0;
  gs_glcdc_init_cfg.blend[GLCDC_FRAME_LAYER_2].start_coordinate.y = 0;
  gs_glcdc_init_cfg.blend[GLCDC_FRAME_LAYER_2].end_coordinate.x   = EW_FRAME_BUFFER_WIDTH;
  gs_glcdc_init_cfg.blend[GLCDC_FRAME_LAYER_2].end_coordinate.y   = EW_FRAME_BUFFER_HEIGHT;

  /* Chromakey */
  gs_glcdc_init_cfg.chromakey[GLCDC_FRAME_LAYER_2].enable      = false;

  /* When enable is false, setting values of structure members under chromakey are ignored. */
  gs_glcdc_init_cfg.chromakey[GLCDC_FRAME_LAYER_2].before.argb = 0x00FFFFFF;
  gs_glcdc_init_cfg.chromakey[GLCDC_FRAME_LAYER_2].after.argb  = 0xFFFFFFFF;

  /* Color look-up table */
  gs_glcdc_init_cfg.clut[GLCDC_FRAME_LAYER_2].enable = clut;

  /* When enable is false, setting values of structure members under clut are ignored. */
  gs_glcdc_init_cfg.clut[GLCDC_FRAME_LAYER_2].p_base = (uint32_t *) FIT_NO_PTR;
  gs_glcdc_init_cfg.clut[GLCDC_FRAME_LAYER_2].start  = 0;
  gs_glcdc_init_cfg.clut[GLCDC_FRAME_LAYER_2].size   = 256;

  /* ---- Graphic 1 setting ---- */
  gs_glcdc_init_cfg.input[GLCDC_FRAME_LAYER_1].p_base = (uint32_t *) NULL; /* Graphic 1 is disable */

  /* When p_base is NULL, setting values of structure members under input[GLCDC_FRAME_LAYER_1] are ignored. */

  /* ---- Hard ware and other setting ---- */
  /* Back ground color */
  gs_glcdc_init_cfg.output.bg_color.argb = 0x00CCCCCC;

  /* Endian */
  gs_glcdc_init_cfg.output.endian = GLCDC_ENDIAN_LITTLE;

  /* Color order */
  gs_glcdc_init_cfg.output.color_order = GLCDC_COLOR_ORDER_RGB;  /* RPBRX72N Envision board dependent setting */

  /* Output clock */
  gs_glcdc_init_cfg.output.clksrc          = GLCDC_CLK_SRC_INTERNAL;
  gs_glcdc_init_cfg.output.clock_div_ratio = GLCDC_PANEL_CLK_DIVISOR_24;

  /* Detection */
  gs_glcdc_init_cfg.detection.vpos_detect  = true;
  gs_glcdc_init_cfg.detection.gr1uf_detect = false;
  gs_glcdc_init_cfg.detection.gr2uf_detect = true;

  /* Interrupt */
  gs_glcdc_init_cfg.interrupt.vpos_enable  = true;
  gs_glcdc_init_cfg.interrupt.gr1uf_enable = false;
  gs_glcdc_init_cfg.interrupt.gr2uf_enable = true;

  /* Call back function register */
  gs_glcdc_init_cfg.p_callback = (void (*) (void *)) glcdc_callback;

  /* -- Initialize a first time interrupt flag -- */
  /* Unintended specified line notification from graphic 2 and graphic 1, 2 underflow is detected only
   for first time after release GLCDC software reset.
   This variable is a flag to skip the first time interrupt processing.
   Refer to Graphic LCD Controller (GLCDC) section of User's Manual: Hardware for details. */
  gs_first_interrupt_flag = false;

  /* ==== GLCDC initialize and start GLCDC operation ==== */

  /* GLCDC initialize */
  ret = R_GLCDC_Open( &gs_glcdc_init_cfg);
  if (GLCDC_SUCCESS != ret)
  {
      while (1)
      {
          nop();
      }
  }

  /* GLCDC port setting */
  R_GLCDC_PinSet();

  s_runtime_cfg.blend = gs_glcdc_init_cfg.blend[GLCDC_FRAME_LAYER_2];
  s_runtime_cfg.input = gs_glcdc_init_cfg.input[GLCDC_FRAME_LAYER_2];
  s_runtime_cfg.chromakey = gs_glcdc_init_cfg.chromakey[GLCDC_FRAME_LAYER_2];

  /* Board dependent port setting */
  board_port_setting();

  /* Start displaying graphics */
  ret = R_GLCDC_Control(GLCDC_CMD_START_DISPLAY, NULL);
  if (GLCDC_SUCCESS != ret)
  {
      while (1)
      {
          nop();
      }
  }

  /* check and clean display info structure */
  if ( !aDisplayInfo )
    return 0;
  memset( aDisplayInfo, 0, sizeof( XDisplayInfo ));

  /* return the current display configuration */
  aDisplayInfo->FrameBuffer    = (void*)EW_FRAME_BUFFER_ADDR;
  aDisplayInfo->DoubleBuffer   = (void*)EW_DOUBLE_BUFFER_ADDR;
  aDisplayInfo->BufferWidth    = EW_FRAME_BUFFER_WIDTH;
  aDisplayInfo->BufferHeight   = EW_FRAME_BUFFER_HEIGHT;
  aDisplayInfo->DisplayWidth   = EW_DISPLAY_WIDTH;
  aDisplayInfo->DisplayHeight  = EW_DISPLAY_HEIGHT;

  #if EW_USE_DOUBLE_BUFFER == 1
    aDisplayInfo->UpdateMode   = EW_BSP_DISPLAY_UPDATE_NORMAL;
  #else
    aDisplayInfo->UpdateMode   = EW_BSP_DISPLAY_UPDATE_PARTIAL;
  #endif

  return 1;
}


/*******************************************************************************
* FUNCTION:
*   EwBspDisplayDone
*
* DESCRIPTION:
*   The function EwBspDisplayDone deinitializes the display hardware.
*
* ARGUMENTS:
*   aDisplayInfo - Display info data structure.
*
* RETURN VALUE:
*   None
*
*******************************************************************************/
void EwBspDisplayDone( XDisplayInfo* aDisplayInfo )
{
  EW_UNUSED_ARG( aDisplayInfo );
}


/*******************************************************************************
* FUNCTION:
*   EwBspDisplayGetUpdateArea
*
* DESCRIPTION:
*   The function EwBspDisplayGetUpdateArea returns the next update area
*   depending on the selected display mode:
*   In case of a synchroneous single-buffer, the function has to return the
*   the rectangular areas that correspond to the horizontal stripes (fields)
*   of the framebuffer.
*   In case of a scratch-pad buffer, the function has to return the subareas
*   that fit into the provided update rectangle.
*   During each display update, this function is called until it returns 0.
*
* ARGUMENTS:
*   aUpdateRect - Rectangular area which should be updated (redrawn).
*
* RETURN VALUE:
*   Returns 1 if a further update area can be provided, 0 otherwise.
*
*******************************************************************************/
int EwBspDisplayGetUpdateArea( XRect* aUpdateRect )
{
  #if EW_USE_DOUBLE_BUFFER == 0

    static int field = 0;

    /* check if last field is already reached */
    if ( field >= EW_NUMBER_OF_FIELDS )
    {
      field = 0;
      return 0;
    }

    /* determine rectangular area of current field */
    #if EW_SURFACE_ROTATION == 0
      *aUpdateRect = EwNewRect( 0, field * EW_FRAME_BUFFER_HEIGHT / EW_NUMBER_OF_FIELDS,
        EW_FRAME_BUFFER_WIDTH, ( field + 1 ) * EW_FRAME_BUFFER_HEIGHT / EW_NUMBER_OF_FIELDS );
    #endif

    #if EW_SURFACE_ROTATION == 90
      *aUpdateRect = EwNewRect( field * EW_FRAME_BUFFER_HEIGHT / EW_NUMBER_OF_FIELDS, 0,
        ( field + 1 ) * EW_FRAME_BUFFER_HEIGHT / EW_NUMBER_OF_FIELDS, EW_FRAME_BUFFER_WIDTH );
    #endif

    #if EW_SURFACE_ROTATION == 180
      *aUpdateRect = EwNewRect( 0, EW_FRAME_BUFFER_HEIGHT - ( field + 1 ) * EW_FRAME_BUFFER_HEIGHT / EW_NUMBER_OF_FIELDS,
        EW_FRAME_BUFFER_WIDTH, EW_FRAME_BUFFER_HEIGHT - field * EW_FRAME_BUFFER_HEIGHT / EW_NUMBER_OF_FIELDS );
    #endif

    #if EW_SURFACE_ROTATION == 270
      *aUpdateRect = EwNewRect( EW_FRAME_BUFFER_HEIGHT - ( field + 1 ) * EW_FRAME_BUFFER_HEIGHT / EW_NUMBER_OF_FIELDS,
        0, EW_FRAME_BUFFER_HEIGHT - field * EW_FRAME_BUFFER_HEIGHT / EW_NUMBER_OF_FIELDS, EW_FRAME_BUFFER_WIDTH );
    #endif

    /* next field */
    field++;

    /* sync on start line of next field to ensure save drawing operation */
    SyncOnLine( field * EW_FRAME_BUFFER_HEIGHT / EW_NUMBER_OF_FIELDS );

    return 1;

  #endif

  return 0;
}


/*******************************************************************************
* FUNCTION:
*   EwBspDisplayWaitForCompletion
*
* DESCRIPTION:
*   The function EwBspDisplayWaitForCompletion is called from the Graphics Engine
*   to ensure that all pending activities of the display system are completed, so
*   that the rendering of the next frame can start.
*   In case of a double-buffering system, the function has to wait until the
*   V-sync has occured and the pending buffer is used by the display controller.
*   In case of an external display controller, the function has to wait until
*   the transfer (update) of the graphics data has been completed and there are
*   no pending buffers.
*
* ARGUMENTS:
*   None
*
* RETURN VALUE:
*   None
*
*******************************************************************************/
void EwBspDisplayWaitForCompletion( void )
{
  #if EW_USE_DOUBLE_BUFFER == 1

    CPU_LOAD_SET_IDLE();

    while( PendingFramebuffer )
      ;

    CPU_LOAD_SET_ACTIVE();

  #endif
}


/*******************************************************************************
* FUNCTION:
*   EwBspDisplayCommitBuffer
*
* DESCRIPTION:
*   The function EwBspDisplayCommitBuffer is called from the Graphics Engine
*   when the rendering of a certain buffer has been completed.
*   The type of buffer depends on the selected framebuffer concept.
*   If the display is running in a double-buffering mode, the function is called
*   after each buffer update in order to change the currently active framebuffer
*   address. Changing the framebuffer address should be synchronized with V-sync.
*   If the system is using an external graphics controller, this function is
*   responsible to start the transfer of the framebuffer content.
*
* ARGUMENTS:
*   aAddress - Address of the framebuffer to be shown on the display.
*   aX,
*   aY       - Origin of the area which has been updated by the Graphics Engine.
*   aWidth,
*   aHeight  - Size of the area which has been updated by the Graphics Engine.
*
* RETURN VALUE:
*   None
*
*******************************************************************************/
void EwBspDisplayCommitBuffer( void* aAddress, int aX, int aY, int aWidth, int aHeight )
{
  #if EW_USE_DOUBLE_BUFFER == 1

    /* set start address of GR2 buffer */
    s_runtime_cfg.input.p_base = (uint32_t *)aAddress;
    R_GLCDC_LayerChange( GLCDC_FRAME_LAYER_2, &s_runtime_cfg );

    /* set pending framebuffer address to be used on next V-sync */
    PendingFramebuffer = (uint32_t)aAddress;

  #else

    /* set start address of GR2 buffer */
    s_runtime_cfg.input.p_base = (uint32_t *)aAddress;
    R_GLCDC_LayerChange( GLCDC_FRAME_LAYER_2, &s_runtime_cfg );

  #endif
}


/*******************************************************************************
* FUNCTION:
*   EwBspDisplaySetClut
*
* DESCRIPTION:
*   The function EwBspDisplaySetClut is called from the Graphics Engine
*   in order to update the hardware CLUT of the current framebuffer.
*   The function is only called when the color format of the framebuffer is
*   Index8 or LumA44.
*
* ARGUMENTS:
*   aClut - Pointer to a color lookup table with 256 entries.
*
* RETURN VALUE:
*   None
*
*******************************************************************************/
void EwBspDisplaySetClut( unsigned long* aClut )
{
  int i;

  for ( i = 0; i < 256; i++ )
  {
    GLCDC.GR2CLUT0[ i ].LONG = aClut[ i ];
  }

  GLCDC.GR2CLUTINT.BIT.SEL = 0;
}

/* msy */
